==> wikindx3_2_2.tar.gz: wikindx3/core/front/FRONT.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

The WIKINDX Team 2005
sirfragalot@users.sourceforge.net
**********************************************************************************/
/*****
* FRONT class
*
* Front page of the system.
*****/
class FRONT
{
// Constructor
	function FRONT($db)
	{
		$this->db = $db;
		include_once("core/messages/MESSAGES.php");
		$this->messages = new MESSAGES();
		include_once("core/template/TEMPLATE.php");
		$this->template = new TEMPLATE('content');
		$this->message = FALSE;
	}
// Display front page information.  If $noMenu, display WIKINDX submenu links
	function display($noMenu = FALSE)
	{
		include_once("core/html/HTML.php");
		$html = new HTML();
		include_once("core/html/MISC.php");
		include_once("core/messages/MESSAGES.php");
		include_once("core/session/SESSION.php");
		$this->session = new SESSION();
		$this->template->setVar('heading', 'WIKINDX');
		$recordset = $this->db->select(array('WKX_config'), array("description", "contactEmail"));
		$row = $this->db->fetchRow($recordset);
		if($noMenu)
		{
			include_once("core/html/MENU.php");
			$menu = new MENU();
			$pString = $menu->noMenu('wikindx');
			$this->template->setVar('noMenu', $pString);
		}
		$pString = $this->message ? $this->message : FALSE;
		$pString .= $html->dbToHtmlTidy($row['description']);
		if($lastChanges = $this->session->getVar("setup_lastChanges"))
			$pString .= $this->getChanges($lastChanges);
		$this->template->setVar('body', $pString);
		if($row['contactEmail'])
		{
			$email = $html->dbToHtmlTidy($row['contactEmail']);
			$email = MISC::a("link", $email, "mailto:$email");
			$this->template->setVar('contact', $email);
		}
		return $this->template->process();
	}
// Get recently added/edited resources
	function getChanges($limit)
	{
		include_once("core/sql/STATEMENTS.php");
		$stmt = new STATEMENTS($this->db);
		include_once("core/icons/LOADICONS.php");
		$icons = new LOADICONS();
		include_once("core/html/TABLE.php");
		include_once("core/styles/BIBSTYLE.php");
		$bibStyle = new BIBSTYLE($this->db, "html");
		include_once("core/user/USER.php");
		$user = new USER($this->db);
// type of CSS class required.
		$icons->getIconInfo('view');
		$icons->getIconInfo('viewmeta');
		$icons->getIconInfo('edit');
		$viewLink = $icons->viewExists ? "imgLink" : "link";
		$editLink = $icons->editExists ? "imgLink" : "link";
		$sqlTotal = $this->db->selectNoExecute(array("WKX_resource"),  
			$stmt->listFields('timestamp'), 
			$stmt->listJoin('timestamp'));
		$recordSet = $this->db->limit($sqlTotal, $limit, 0);
		$index = 0;
		$pString = MISC::br() . "&nbsp;" . MISC::br() . 
			MISC::h($this->messages->text("resources", "lastChanges"), 4);
		$pString .= TABLE::tableStart(FALSE, 0, 0, 0, "left");
		while($row = $this->db->loopRecordSet($recordSet))
		{
			$links = array();
			$userAddEdit = $user->displayUserAddEdit($row['addUserIdResource'], $row['editUserIdResource']);
// tidy up $userAddEdit
			$userArray = explode("&nbsp;&nbsp;&nbsp;", $userAddEdit);
			if(array_key_exists(1, $userArray))
				$info = trim(preg_replace("/&nbsp;+/", ' ', $userArray[1]));
			else
			{
				$info = trim(preg_replace("/&nbsp;+/", ' ', $userArray[0]));
				$info = str_replace("<br />", '', $userArray[0]);
			}
			$view = ($row['quotes'] || $row['paraphrases'] || $row['musings']) ? 
				$icons->viewmeta : $icons->view;
			$links[] = MISC::a("$viewLink", "&nbsp;" . $view . 
				"&nbsp;", "index.php?action=resourceView" . 
				htmlentities("&id=" . $row['resourceId']));
			$class = $index % 2 ? 'alternate2' : 'alternate1';
			$timeStamp = MISC::br() . MISC::span(str_replace(" ", "&nbsp;", $row['timestamp']), 'hint');
			$info .= $timeStamp;
			$pString .= TABLE::trStart();
			$pString .= TABLE::td($info, $class, "left", "top");
			$pString .= TABLE::td("&nbsp;&nbsp;&nbsp;&nbsp;", $class, "left", "top");
			$pString .= TABLE::td($bibStyle->process($row), $class);
			$pString .= TABLE::td(implode("&nbsp;&nbsp;", $links), $class, "right", "top");
			$pString .= TABLE::trEnd();
			$index++;
		}
		$pString .= TABLE::tableEnd();
		return $pString;
	}
}
?>

==> wikindx3_3_1.tar.gz: wikindx3/core/front/FRONT.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

The WIKINDX Team 2006
sirfragalot@users.sourceforge.net
**********************************************************************************/
/*****
* FRONT class
*
* Front page of the system.
*****/
class FRONT
{
// Constructor
	function FRONT($db)
	{
		$this->db = $db;
		include_once("core/messages/MESSAGES.php");
		$this->messages = new MESSAGES();
		include_once("core/template/TEMPLATE.php");
		$this->template = new TEMPLATE('content');
		$this->message = FALSE;
	}
// Display front page information.  If $noMenu, display WIKINDX submenu links
	function display($noMenu = FALSE)
	{
		include_once("core/html/HTML.php");
		$html = new HTML();
		include_once("core/html/MISC.php");
		include_once("core/messages/MESSAGES.php");
		include_once("core/session/SESSION.php");
		$this->session = new SESSION();
		$this->template->setVar('heading', 'WIKINDX');
		$recordset = $this->db->select(array('WKX_config'), array("description", "contactEmail"));
		$row = $this->db->fetchRow($recordset);
		if($noMenu)
		{
			include_once("core/html/MENU.php");
			$menu = new MENU();
			$pString = $menu->noMenu('wikindx');
			$this->template->setVar('noMenu', $pString);
		}
		$pString = $this->message ? $this->message : FALSE;
		$pString .= $html->dbToHtmlTidy($row['description']);
		if($lastChanges = $this->session->getVar("setup_lastChanges"))
			$pString .= $this->getChanges($lastChanges);
		$this->template->setVar('body', $pString);
		if($row['contactEmail'])
		{
			$email = $html->dbToHtmlTidy($row['contactEmail']);
			$email = MISC::a("link", $email, "mailto:$email");
			$this->template->setVar('contact', $email);
		}
		return $this->template->process();
	}
// Get recently added/edited resources
	function getChanges($limit)
	{
// If no resources, return FALSE
		$resultSet = $this->db->select(array('WKX_resource'), array('id'));
		if(!$this->db->numRows($resultSet))
			return FALSE;
		include_once("core/sql/STATEMENTS.php");
		$stmt = new STATEMENTS($this->db);
		include_once("core/icons/LOADICONS.php");
		$icons = new LOADICONS();
		include_once("core/html/TABLE.php");
		include_once("core/styles/BIBSTYLE.php");
		$bibStyle = new BIBSTYLE($this->db, "html");
		include_once("core/user/USER.php");
		$user = new USER($this->db);
// type of CSS class required.
		$icons->getIconInfo('view');
		$icons->getIconInfo('viewmeta');
		$icons->getIconInfo('edit');
		$viewLink = $icons->viewExists ? "imgLink" : "link";
		$editLink = $icons->editExists ? "imgLink" : "link";
		$sqlTotal = $this->db->selectNoExecute(array("WKX_resource"),  
			$stmt->listFields('timestamp'), 
			$stmt->listJoin('timestamp'));
		$recordSet = $this->db->limit($sqlTotal, $limit, 0);
		$index = 0;
		$pString = MISC::br() . "&nbsp;" . MISC::br() . 
			MISC::h($this->messages->text("resources", "lastChanges"), 4);
		$pString .= TABLE::tableStart(FALSE, 0, 0, 0, "left");
		while($row = $this->db->loopRecordSet($recordSet))
		{
			$links = array();
			$info = FALSE;
			if($this->session->getVar('setup_multiUser'))
			{
				$userAddEdit = $user->displayUserAddEdit($row['addUserIdResource'], $row['editUserIdResource']);
		// tidy up $userAddEdit
				$userArray = explode("&nbsp;&nbsp;&nbsp;", $userAddEdit);
				if(array_key_exists(1, $userArray))
					$info = trim(preg_replace("/&nbsp;+/", ' ', $userArray[1]));
				else
				{
					$info = trim(preg_replace("/&nbsp;+/", ' ', $userArray[0]));
					$info = str_replace("<br />", '', $userArray[0]);
				}
				$info .= MISC::br();
			}
			$timeStamp = MISC::span(str_replace(" ", "&nbsp;", $row['timestamp']), 'hint');
			$info .= $timeStamp;
			$view = ($row['quotes'] || $row['paraphrases'] || $row['musings']) ? 
				$icons->viewmeta : $icons->view;
			$links[] = MISC::a("$viewLink", "&nbsp;" . $view . 
				"&nbsp;", "index.php?action=resourceView" . 
				htmlentities("&id=" . $row['resourceId']));
			$class = $index % 2 ? 'alternate2' : 'alternate1';
			$pString .= TABLE::trStart();
//			if($this->session->getVar('setup_multiUser'))
//			{
				$pString .= TABLE::td($info, $class, "left", "top");
				$pString .= TABLE::td("&nbsp;&nbsp;&nbsp;&nbsp;", $class, "left", "top");
//			}
			$pString .= TABLE::td($bibStyle->process($row), $class);
			$pString .= TABLE::td(implode("&nbsp;&nbsp;", $links), $class, "right", "top");
			$pString .= TABLE::trEnd();
			$allIds[] = $row['resourceId'];
			$index++;
		}
		if(isset($allIds))
			$this->session->setVar('list_allIds', base64_encode(serialize($allIds)));
		else
			$this->session->delVar("list_allIds");
		$pString .= TABLE::tableEnd();
		return $pString;
	}
}
?>
